@@ -10,6 +10,4 @@ class snap_deductions(Variable):
     definition_period = YEAR
     reference = "https://www.law.cornell.edu/uscode/text/7/2014#e"
 
-    def formula(spm_unit, period, parameters):
-        snap_deductions = parameters(period).gov.usda.snap.income.deductions
-        return add(spm_unit, period, snap_deductions.allowed)
+    formula = sum_of_variables("gov.usda.snap.income.deductions.allowed")
